@@ -238,7 +238,7 @@ is reached using C<eof>
 =item expand_symlinks(FILENAME)
 
 expand the symlinks in the absolute filename:
-C<expand_symlinks("/etc/X11/X")> gives "/usr/X11R6/bin/XFree86"
+C<expand_symlinks("/etc/X11/X")> gives "/usr/bin/Xorg"
 
 =item openFileMaybeCompressed(FILENAME)
 
@@ -585,6 +585,15 @@ find the first corresponding magic in FILENAME. eg of LIST:
     [ 'empty', 0, "\0\0\0\0" ],
     [ 'grub', 0, "\xEBG", 0x17d, "stage1 \0" ],
     [ 'lilo', 0x2,  "LILO" ],
+    sub { my ($F) = @_;
+	  #- standard grub has no good magic (Mageia's grub is patched to have "GRUB" at offset 6)
+	  #- so scanning a range of possible places where grub can have its string
+	  my ($min, $max, $magic) = (0x176, 0x181, "GRUB \0");
+	  my $tmp;
+	  sysseek($F, 0, 0) && sysread($F, $tmp, $max + length($magic)) or return;
+	  substr($tmp, 0, 2) eq "\xEBH" or return;
+	  index($tmp, $magic, $min) >= 0 && "grub";
+      },
 
 where each entry is [ magic_name, offset, string, offset, string, ... ].
 
@@ -624,8 +633,6 @@ size of swap + memory
 size of RAM as reported by the BIOS (it is a round number that can be
 displayed or given as "mem=128M" to the kernel)
 
-!! "mem=..." is dangerous in 2.4 kernels
-
 =item gettimeofday()
 
 returns the epoch in microseconds
@@ -828,6 +835,6 @@ our @ISA = qw(Exporter);
 # perl_checker: RE-EXPORT-ALL
 our @EXPORT = map { @$_ } map { values %{'MDK::Common::' . $_ . 'EXPORT_TAGS'} } grep { /::$/ } keys %MDK::Common::;
 
-our $VERSION = "1.2.29";
+our $VERSION = "1.2.30";
 
 1;
